%
% An unofficial LaTeX class for University of Iceland Ph.D thesis
% patterned after rules for Ph.D. thesis
% in the School of Engineering and Natural Sciences
%
% Creator and maintainer Einar Arnason, einararn@hi.is
% 23-10-2014 version 0.1
% Copyright (C) 2014 Einar Arnason
% Permission is granted to copy, distribute and/or modify this document
% under the terms of the GNU Free Documentation License, Version 1.3
% or any later version published by the Free Software Foundation;
% with no Invariant Sections, no Front-Cover Texts, and no Back-Cover Texts.
% A copy of the license is available at http://www.gnu.org/
%
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{ui-phdthesis}[23/10/2014, v0.1]
\RequirePackage[utf8]{inputenc}
\RequirePackage{t1enc}
\RequirePackage[icelandic,american]{babel}
\RequirePackage{ifthen}
\RequirePackage{calc}
\AtEndOfClass{\RequirePackage{microtype}}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions*
\LoadClass[10pt]{article}
\RequirePackage{times}      % Loads the Times-Roman Fonts
\RequirePackage{mathptmx}   % Loads the Times-Roman Math Fonts
\RequirePackage{ifpdf}
%\RequirePackage{showframe}  %show page geometry
\RequirePackage{eso-pic}  %show page geometry
\RequirePackage{amsmath,amsfonts,amssymb}
\RequirePackage{graphicx,xcolor}
\RequirePackage{booktabs}
\RequirePackage{authblk}
\RequirePackage{textcomp}
\RequirePackage{abstract}
\RequirePackage{emptypage}
\RequirePackage{url}
\RequirePackage{natbib}
\bibliographystyle{apalike}
\RequirePackage{enumitem}
%
%
\RequirePackage[twoside,%
                inner=3.0cm,%
                outer=2.5cm,%
                top=2.5cm,%
                bottom=3.0cm,%
                headheight=14.49998pt,%
                footskip=1.5cm,%
                b5paper]{geometry}%
                
\RequirePackage[labelfont={it},%
                labelsep=period,%
                font={it},%
                justification=raggedright]{caption}
%
\RequirePackage{lastpage}  % Number of pages in the document
\RequirePackage{fancyhdr}  % custom headers/footers
\pagestyle{fancy} % choose the "fancy" pagestyle
%
%
\setlength{\parskip}{0pt}
%
\definecolor{color1}{RGB}{0,0,0} % Color of section headings
\definecolor{uicolor}{cmyk}{1,.57,0,.4}% Color of the University of Iceland
%
\renewcommand{\thetable}{\arabic{section}.\arabic{table}}   
\renewcommand{\thefigure}{\arabic{section}.\arabic{figure}}
%
% We automate insertion of pdffiles one page at a time using
% includegraphics
%
\makeatletter
\newcounter{imagepage}
\newcommand*{\foreachpage}[2]{%
  \begingroup
    \sbox0{\includegraphics{#1}}%
    \xdef\foreachpage@num{\the\pdflastximagepages}%
  \endgroup
  \setcounter{imagepage}{0}%
  \@whilenum\value{imagepage}<\foreachpage@num\do{%
    \stepcounter{imagepage}%
    #2\relax
  }%
}
\makeatother
%
\newcommand{\insertpdffile}[7]{%
\newpage
\let\oldleftmark=\leftmark
\let\oldrightmark=\rightmark
\renewcommand{\leftmark}{\footnotesize\sffamily#1}
\renewcommand{\rightmark}{\footnotesize\sffamily#1}
\vspace*{38mm}
%
\noindent\colorbox{uicolor}{\parbox{\textwidth}{\color{white}\hfill\Huge\sffamily\bfseries #1\hspace*{15mm}}}
{\addcontentsline{toc}{section}{#1}}
\vspace*{0.5ex}

\vspace{1ex}\noindent{\sffamily\bfseries #2}
\vspace*{0.5ex}

\noindent#3
\vspace*{0.5ex}

\noindent#4
\vspace*{1.5ex}

\noindent#5
\vspace*{1.5ex}

\noindent#6
\clearpage
\foreachpage{#7}{%
  \newpage   
  \begingroup 
    \centering
    \includegraphics[
      page=\value{imagepage},
      width=\textwidth,  
      height=\textheight,
      keepaspectratio,
    ]{#7}%
    \newpage
  \endgroup
}
\let\leftmark=\oldleftmark
\let\rightmark=\oldrightmark
}
%
% headers and footers
\RequirePackage[explicit]{titlesec}
\titleformat{\section}
 {\color{color1}\LARGE\sffamily\bfseries}
 {\thesection}
 {0.5em}
 {#1}
 []
%
\titleformat{\subsection}
  {\Large\sffamily\bfseries}
  {\thesubsection}
  {0.5em}
  {#1}
  []
%
\titleformat{\subsubsection}
  {\sffamily\normalsize\sffamily\bfseries}
  {\thesubsubsection}
  {0.5em}
  {#1}
  []  
%  
\titleformat{\paragraph}[runin]
  {\sffamily\normalsize}
  {}
  {0em}
  {#1} 
%
\renewcommand{\beforetitleunit}{1ex}
\titlespacing*{\section}{0pc}{54pt plus 1pt minus 1pt}{1pc}
\titlespacing*{\subsection}{0pt}{24pt}{10pt}
\titlespacing*{\subsubsection}{0pt}{18pt}{6pt}
\titlespacing*{\paragraph}{0pc}{1.5ex \@plus2pt \@minus1pt}{10pt}
\newcommand{\sectionbreak}{\cleardoublepage\null}
%  
%
% tableofcontents set-up
%
\newlength{\tocsep} 
\setlength\tocsep{1.5pc} 
% Sets the indentation of the sections in the table of contents
\newlength{\tocsepsub} 
\setlength\tocsepsub{3.0pc} 
% Sets the indentation of the subsections in the table of contents
\newlength{\tocsepsubsub} 
\setlength\tocsepsubsub{4.5pc} 
% Sets the indentation of the subsections in the table of contents
\setcounter{tocdepth}{4} % Show only three levels in the table of contents section: sections, subsections and subsubsections
\usepackage{titletoc}
\contentsmargin{0cm}
\titlecontents{section}[\tocsep]
  {\addvspace{4pt}\small\bfseries\sffamily}
  {\contentslabel[\thecontentslabel]{\tocsep}}
  {}
  {\hfill\thecontentspage}
  []
\titlecontents{subsection}[\tocsepsub]
  {\addvspace{2pt}\small\sffamily}
  {\contentslabel[\thecontentslabel]{\tocsepsub}}
  {}
  {\ \titlerule*[.5pc]{.}\ \thecontentspage}
  []
\titlecontents*{subsubsection}[\tocsepsubsub]
  {\footnotesize\sffamily}
  {\contentslabel[\thecontentslabel]{\tocsepsubsub}}
  {}
  {\ \titlerule*[.5pc]{.}\ \thecontentspage}
  [\ \textbullet\ ]  
%
%-----------------------------------------------
\let\oldbibliography\thebibliography
\renewcommand{\thebibliography}[1]{%
\addcontentsline{toc}{section}{\hspace*{-\tocsep}\refname}%
\oldbibliography{#1}%
\setlength\itemsep{0pt}%
}
%%
\makeatletter
\def\thesisauthor#1{\gdef\@thesisauthor{#1}}					
\def\thesistitle#1{\gdef\@thesistitle{#1}} 					
\def\thesisshorttitle#1{\gdef\@thesisshorttitle{#1}}
\def\thesismonth#1{\gdef\@thesismonth{#1}}					
\def\thesisyear#1{\gdef\@thesisyear{#1}}
\def\thesisdegree#1{\gdef\@thesisdegree{#1}}
\def\thesisfield#1{\gdef\@thesisfield{#1}}
\def\thesisschool#1{\gdef\@thesisschool{#1}}
\def\thesisfaculty#1{\gdef\@thesisfaculty{#1}}					
\def\thesisaddress#1{\gdef\@thesisaddress{#1}}
\def\thesispostalcode#1{\gdef\@thesispostalcode{#1}}
\def\thesistelephone#1{\gdef\@thesistelephone{#1}}				
\def\thesisprinter#1{\gdef\@thesisprinter{#1}}					
\def\thesisadvisor#1{\gdef\@thesisadvisor{#1}}
\def\thesiscommittee#1{\gdef\@thesiscommittee{#1}}
\def\thesisopponents#1{\gdef\@thesisopponents{#1}}
\def\thesiskeywords#1{\gdef\@thesiskeywords{#1}}
\def\thesisISBN#1{\gdef\@thesisISBN{#1}}           				
\makeatother
%
\makeatletter
\newcommand\BackgroundPic{
\put(0,0){
\parbox[b][\paperheight]{\paperwidth}{
\vfill
\centering
\hspace*{-0.6cm}
\includegraphics[width=2\paperwidth,height=\paperheight,
keepaspectratio]{UIblueribbon}
}}
\setlength{\unitlength}{\paperwidth}
\begin{picture}(0,0)(0,-0.15)
\put(0,0){\color{white}\parbox{1\paperwidth}{\centering\bfseries\sffamily
    \Large Faculty of \@thesisfaculty \\ 
University of Iceland\\
\@thesisyear}}
\end{picture}
}
\makeatother

\makeatletter
\def\makecovertitlepage{
  \thispagestyle{empty}
  \setcounter{page}{1}
  \vspace*{3.35mm}
  {\centering\includegraphics[width=24.76mm]{HIlogo}\par}
  \vspace*{25.25mm}
  {\centering\bfseries\sffamily\Large{\@thesistitle}\par}
  \vspace*{30mm}
  {\centering\sffamily\Large{\@thesisauthor}\par}
  \vspace*{\fill}
  \AddToShipoutPicture*{\BackgroundPic}
\thispagestyle{empty}
\cleardoublepage
}
\makeatother
%
\makeatletter
\def\makeinnertitlepage{%
  {\setlength{\parskip}{0pt}
  \thispagestyle{empty}
  \setcounter{page}{1}
  \pagenumbering{roman}
  \cfoot{\thepage}
  \vspace*{\fill}
  {\centering\bfseries\sffamily\LARGE{\@thesistitle} \par}
  \vspace*{16.83mm}
  {\centering\sffamily\Large {\@thesisauthor}\par}
  \vspace*{16mm}
  {\centering\sffamily\large Dissertation submitted in partial
    fulfillment of a \newline
    {\centering\sffamily\itshape\large\@thesisdegree} degree in 
     {\@thesisfield}\par} 
  \vspace*{14.3mm}
  {\centering\sffamily\large Advisor\\ {\@thesisadvisor}\par}
  \vspace*{10mm}
  {\centering\sffamily\large PhD Committee\\{\@thesiscommittee}\par}
  \vspace*{10mm}
  {\centering\sffamily\large Opponents\\ {\@thesisopponents}\par}
\vspace*{\fill}
  {\centering\sffamily\large Faculty of {\@thesisfaculty}\\}
  {\centering\sffamily\large {\@thesisschool}\\}
  {\centering\sffamily\large University of Iceland\\}
  {\centering\sffamily\large Reykjavik,
    {\@thesismonth}~{\@thesisyear}\\}
}
\clearpage
}
\makeatother
%
\makeatletter
\def\makesaurblad{%
{\scriptsize
  {\setlength{\parskip}{0cm plus0mm minus0mm}
  \thispagestyle{empty}
  \vspace*{\fill}
{\noindent\@thesistitle\\}
{\noindent\@thesisshorttitle\\}
\noindent Dissertation submitted in partial fulfillment of a {\itshape
  Philosophiae Doctor} degree in {\@thesisfield\par}
\vspace*{6mm}
\noindent Copyright \textcopyright~{\@thesisauthor~\@thesisyear\\}
\noindent All rights reserved\par
\vspace*{10.1mm}
\noindent Faculty of {\@thesisfaculty\\}
\noindent {\@thesisschool\\}
\noindent University of Iceland\\
\noindent{\@thesisaddress\\}
\noindent{\@thesispostalcode}, Reykjavik\\
\noindent Iceland\par
\vspace*{6mm}
\noindent Telephone: {\@thesistelephone\par}
\vspace*{14.3mm}
\noindent Bibliographic information:\\
\noindent{\@thesisauthor, \@thesisyear, {\itshape \@thesistitle}, PhD
  dissertation, Faculty of {\@thesisfaculty}, University of Iceland,
  \pageref{LastPage}~pp. \par
}
\vspace*{9.25mm}
\noindent ISBN~{\@thesisISBN\par}
\vspace*{6mm}
\noindent Printing: {\@thesisprinter\\}
\noindent Reykjavik, Iceland, {\@thesismonth~\@thesisyear\par}
}
\clearpage
}}
\makeatother
\selectlanguage{american}
%
\renewcommand{\abstractname}{Abstract}
\newcommand\thesisabstract[1]{%
\thispagestyle{empty}
\section*{Abstract}
\addcontentsline{toc}{section}{Abstract}
{#1}
\cleardoublepage
}
%
\newcommand\thesisutdrattur[1]{%
\renewcommand{\abstractname}{Útdráttur}
\thispagestyle{empty}
\section*{Útdráttur}
\addcontentsline{toc}{section}{Útdráttur}
{\selectlanguage{icelandic}#1}
\cleardoublepage
}
%
\newcommand\thesispreface[2]{%
{\ifthenelse{\equal{#1}{TRUE}}{%
\thispagestyle{empty}
\section*{Preface}
\addcontentsline{toc}{section}{Preface}
#2
\cleardoublepage
}{}
}
{\ifthenelse{\equal{#1}{FALSE}}{}{}}
}
%
\newcommand\thesisdedication[2]{%
{\ifthenelse{\equal{#1}{TRUE}}{%
\thispagestyle{empty}
\addcontentsline{toc}{section}{Dedication}
\vspace*{50mm}
\begin{center}
  {\normalfont\itshape Dedication\\\vspace*{2ex}#2}
\end{center}
\cleardoublepage
}{}
}
{\ifthenelse{\equal{#1}{FALSE}}{}{}}
}
%
\newcommand\thesisabbreviations[2]{%
{\ifthenelse{\equal{#1}{TRUE}}{%
\section*{Abbreviations}
\addcontentsline{toc}{section}{Abbreviations}
  {#2}
\renewcommand{\leftmark}{\normalfont\footnotesize\sffamily\nouppercase{Abbreviations}}
\renewcommand{\rightmark}{}
\cleardoublepage
}{}
}
{\ifthenelse{\equal{#1}{FALSE}}{}{}}
}
%
\newcommand\thesisacknowledgments[2]{%
{\ifthenelse{\equal{#1}{TRUE}}{%
\section*{Acknowledgments}
\addcontentsline{toc}{section}{Acknowledgments}
  {#2}
\renewcommand{\leftmark}{\normalfont\footnotesize\sffamily\nouppercase{Acknowledgments}}
\renewcommand{\rightmark}{}
\cleardoublepage
}{}
}
{\ifthenelse{\equal{#1}{FALSE}}{}{}}
}
%
\newcommand\thesislists{%
\let\oldleftmark=\leftmark
\let\oldrightmark=\rightmark
\renewcommand{\contentsname}{Table of Contents}
\thispagestyle{empty}
\addcontentsline{toc}{section}{Table of Contents}
\renewcommand{\leftmark}{\normalfont\footnotesize\sffamily\contentsname}
\renewcommand{\rightmark}{}
\tableofcontents
\cleardoublepage
\addcontentsline{toc}{section}{\listfigurename}
\renewcommand{\leftmark}{\normalfont\footnotesize\sffamily\nouppercase\listfigurename}
\renewcommand{\rightmark}{}
\listoffigures
\cleardoublepage
\listoftables
\addcontentsline{toc}{section}{\listtablename}
\renewcommand{\leftmark}{\normalfont\footnotesize\sffamily\nouppercase\listtablename}
\renewcommand{\rightmark}{}
\cleardoublepage
\let\leftmark=\oldleftmark
\let\rightmark=\oldrightmark
}
%
\newcommand\thesisbody{%
\fancyhf{}        % clear all headers and footers
\pagenumbering{arabic}
% Now set the headers
%\fancyhead[LE,RO]{\footnotesize\thepage}
\fancyhead[LE]{\normalfont\footnotesize\sffamily\nouppercase{\leftmark}}
\fancyhead[RO]{\normalfont\footnotesize\sffamily\nouppercase{\rightmark}}
%\fancyhead{}
\fancyfoot[LE]{\thepage}%
\fancyfoot[RO]{\thepage}%
\pagestyle{fancy} % Enables the custom headers/footers
% % Headers
% \lhead{}%
% \chead{}%
% \rhead{}%
% % Footers
%\lfoot{}%
\renewcommand{\cfoot}{}%
% \rfoot{}%
}
%
%
\newenvironment{mypaper}[2]{%
\noindent
  \begin{tabular}{p{10ex}p{0.75\textwidth}}
  \textbf{#1:}& {#2}\\
  \end{tabular}
\par
}
{}

%
\newcommand\thesislistofpapers[2]{%
{\ifthenelse{\equal{#1}{TRUE}}{%
\section*{List of Original Papers}
\addcontentsline{toc}{section}{List of Original Papers}
  {#2}
\renewcommand{\leftmark}{\normalfont\footnotesize\sffamily\nouppercase{List
    of Original Papers}} 
\renewcommand{\rightmark}{}
\cleardoublepage
}{}
}
{\ifthenelse{\equal{#1}{FALSE}}{}{}}
}
